@@ -141,6 +141,10 @@ class Opcode(int, Enum):
     FOLDERS_DELETE = 276
     NOTIF_FOLDERS = 277
 
+    GET_QR = 288
+    GET_QR_STATUS = 289
+    LOGIN_BY_QR = 291
+
 
 class ChatType(str, Enum):
     DIALOG = "DIALOG"
@@ -192,6 +196,7 @@ class AttachType(str, Enum):
     STICKER = "STICKER"
     AUDIO = "AUDIO"
     CONTROL = "CONTROL"
+    CONTACT = "CONTACT"
 
 
 class FormattingType(str, Enum):
@@ -211,3 +216,8 @@ class MarkupType(str, Enum):
 class ContactAction(str, Enum):
     ADD = "ADD"
     REMOVE = "REMOVE"
+
+
+class ReadAction(str, Enum):
+    READ_MESSAGE = "READ_MESSAGE"
+    READ_REACTION = "READ_REACTION"
